@@ -219,7 +219,7 @@ class Resource(object):
     #: The name of this resource.
     name = Body("name")
     #: The location of this resource.
-    location = Header("location")
+    location = Header("Location")
 
     #: Mapping of accepted query parameter names.
     _query_mapping = QueryParameters()
@@ -290,7 +290,10 @@ class Resource(object):
             if name in self._body:
                 return self._body[name]
             else:
-                return self._body[self._alternate_id()]
+                try:
+                    return self._body[self._alternate_id()]
+                except KeyError:
+                    return None
         else:
             return object.__getattribute__(self, name)
 
@@ -403,10 +406,7 @@ class Resource(object):
         be a string already representing an ID, it is returned.
         """
         if isinstance(value, Resource):
-            # Don't check _alternate_id unless we need to. It's an uncommon
-            # case and it involves looping through the class' dict.
-            id = value.id or getattr(value, value._alternate_id(), None)
-            return id
+            return value.id
         else:
             return value
 
