@@ -11,12 +11,14 @@
 # under the License.
 
 import mock
+import uuid
 
 from openstack.network.v2 import _proxy
 from openstack.network.v2 import address_scope
 from openstack.network.v2 import agent
 from openstack.network.v2 import availability_zone
 from openstack.network.v2 import extension
+from openstack.network.v2 import flavor
 from openstack.network.v2 import floating_ip
 from openstack.network.v2 import health_monitor
 from openstack.network.v2 import listener
@@ -28,6 +30,11 @@ from openstack.network.v2 import network_ip_availability
 from openstack.network.v2 import pool
 from openstack.network.v2 import pool_member
 from openstack.network.v2 import port
+from openstack.network.v2 import qos_bandwidth_limit_rule
+from openstack.network.v2 import qos_dscp_marking_rule
+from openstack.network.v2 import qos_minimum_bandwidth_rule
+from openstack.network.v2 import qos_policy
+from openstack.network.v2 import qos_rule_type
 from openstack.network.v2 import quota
 from openstack.network.v2 import rbac_policy
 from openstack.network.v2 import router
@@ -40,6 +47,10 @@ from openstack.network.v2 import vpn_service
 from openstack.tests.unit import test_proxy_base
 
 
+QOS_POLICY_ID = 'qos-policy-id-' + uuid.uuid4().hex
+QOS_RULE_ID = 'qos-rule-id-' + uuid.uuid4().hex
+
+
 class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestNetworkProxy, self).setUp()
@@ -287,6 +298,25 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_network_update(self):
         self.verify_update(self.proxy.update_network, network.Network)
 
+    def test_flavor_create_attrs(self):
+        self.verify_create(self.proxy.create_flavor, flavor.Flavor)
+
+    def test_flavor_delete(self):
+        self.verify_delete(self.proxy.delete_flavor, flavor.Flavor, True)
+
+    def test_flavor_find(self):
+        self.verify_find(self.proxy.find_flavor, flavor.Flavor)
+
+    def test_flavor_get(self):
+        self.verify_get(self.proxy.get_flavor, flavor.Flavor)
+
+    def test_flavor_update(self):
+        self.verify_update(self.proxy.update_flavor, flavor.Flavor)
+
+    def test_flavors(self):
+        self.verify_list(self.proxy.flavors, flavor.Flavor,
+                         paginated=True)
+
     def test_network_ip_availability_find(self):
         self.verify_find(self.proxy.find_network_ip_availability,
                          network_ip_availability.NetworkIPAvailability)
@@ -382,6 +412,175 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_port_update(self):
         self.verify_update(self.proxy.update_port, port.Port)
 
+    def test_qos_bandwidth_limit_rule_create_attrs(self):
+        self.verify_create(
+            self.proxy.create_qos_bandwidth_limit_rule,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_bandwidth_limit_rule_delete(self):
+        self.verify_delete(
+            self.proxy.delete_qos_bandwidth_limit_rule,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            False, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID},)
+
+    def test_qos_bandwidth_limit_rule_delete_ignore(self):
+        self.verify_delete(
+            self.proxy.delete_qos_bandwidth_limit_rule,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            True, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
+
+    def test_qos_bandwidth_limit_rule_find(self):
+        self.verify_find(self.proxy.find_qos_bandwidth_limit_rule,
+                         qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+                         path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_bandwidth_limit_rule_get(self):
+        self.verify_get(
+            self.proxy.get_qos_bandwidth_limit_rule,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_bandwidth_limit_rules(self):
+        self.verify_list(
+            self.proxy.qos_bandwidth_limit_rules,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            paginated=False,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_bandwidth_limit_rule_update(self):
+        self.verify_update(
+            self.proxy.update_qos_bandwidth_limit_rule,
+            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+            path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_dscp_marking_rule_create_attrs(self):
+        self.verify_create(
+            self.proxy.create_qos_dscp_marking_rule,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_dscp_marking_rule_delete(self):
+        self.verify_delete(
+            self.proxy.delete_qos_dscp_marking_rule,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            False, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID},)
+
+    def test_qos_dscp_marking_rule_delete_ignore(self):
+        self.verify_delete(
+            self.proxy.delete_qos_dscp_marking_rule,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            True, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
+
+    def test_qos_dscp_marking_rule_find(self):
+        self.verify_find(self.proxy.find_qos_dscp_marking_rule,
+                         qos_dscp_marking_rule.QoSDSCPMarkingRule,
+                         path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_dscp_marking_rule_get(self):
+        self.verify_get(
+            self.proxy.get_qos_dscp_marking_rule,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_dscp_marking_rules(self):
+        self.verify_list(
+            self.proxy.qos_dscp_marking_rules,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            paginated=False,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_dscp_marking_rule_update(self):
+        self.verify_update(
+            self.proxy.update_qos_dscp_marking_rule,
+            qos_dscp_marking_rule.QoSDSCPMarkingRule,
+            path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_minimum_bandwidth_rule_create_attrs(self):
+        self.verify_create(
+            self.proxy.create_qos_minimum_bandwidth_rule,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_minimum_bandwidth_rule_delete(self):
+        self.verify_delete(
+            self.proxy.delete_qos_minimum_bandwidth_rule,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            False, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID},)
+
+    def test_qos_minimum_bandwidth_rule_delete_ignore(self):
+        self.verify_delete(
+            self.proxy.delete_qos_minimum_bandwidth_rule,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            True, input_path_args=["resource_or_id", QOS_POLICY_ID],
+            expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
+
+    def test_qos_minimum_bandwidth_rule_find(self):
+        self.verify_find(self.proxy.find_qos_minimum_bandwidth_rule,
+                         qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+                         path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_minimum_bandwidth_rule_get(self):
+        self.verify_get(
+            self.proxy.get_qos_minimum_bandwidth_rule,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_minimum_bandwidth_rules(self):
+        self.verify_list(
+            self.proxy.qos_minimum_bandwidth_rules,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            paginated=False,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+
+    def test_qos_minimum_bandwidth_rule_update(self):
+        self.verify_update(
+            self.proxy.update_qos_minimum_bandwidth_rule,
+            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+            path_args={'qos_policy_id': QOS_POLICY_ID})
+
+    def test_qos_policy_create_attrs(self):
+        self.verify_create(self.proxy.create_qos_policy, qos_policy.QoSPolicy)
+
+    def test_qos_policy_delete(self):
+        self.verify_delete(self.proxy.delete_qos_policy, qos_policy.QoSPolicy,
+                           False)
+
+    def test_qos_policy_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_qos_policy, qos_policy.QoSPolicy,
+                           True)
+
+    def test_qos_policy_find(self):
+        self.verify_find(self.proxy.find_qos_policy, qos_policy.QoSPolicy)
+
+    def test_qos_policy_get(self):
+        self.verify_get(self.proxy.get_qos_policy, qos_policy.QoSPolicy)
+
+    def test_qos_policies(self):
+        self.verify_list(self.proxy.qos_policies, qos_policy.QoSPolicy,
+                         paginated=False)
+
+    def test_qos_policy_update(self):
+        self.verify_update(self.proxy.update_qos_policy, qos_policy.QoSPolicy)
+
+    def test_qos_rule_types(self):
+        self.verify_list(self.proxy.qos_rule_types, qos_rule_type.QoSRuleType,
+                         paginated=False)
+
     def test_quota_delete(self):
         self.verify_delete(self.proxy.delete_quota, quota.Quota, False)
 
@@ -546,6 +745,15 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
                          security_group_rule.SecurityGroupRule,
                          paginated=False)
 
+    def test_segment_create_attrs(self):
+        self.verify_create(self.proxy.create_segment, segment.Segment)
+
+    def test_segment_delete(self):
+        self.verify_delete(self.proxy.delete_segment, segment.Segment, False)
+
+    def test_segment_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_segment, segment.Segment, True)
+
     def test_segment_find(self):
         self.verify_find(self.proxy.find_segment, segment.Segment)
 
@@ -555,6 +763,9 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_segments(self):
         self.verify_list(self.proxy.segments, segment.Segment, paginated=False)
 
+    def test_segment_update(self):
+        self.verify_update(self.proxy.update_segment, segment.Segment)
+
     def test_subnet_create_attrs(self):
         self.verify_create(self.proxy.create_subnet, subnet.Subnet)
 
